@@ -14,9 +14,12 @@ from . import recolor
 from . import resize
 from . import text2icon
 from . import shadow
+from . import render
 # IMPORT SUBCMD DEF HERE
 # SUB COMMONDS DEF]
 
+from ezpp import __version__
+
 
 def main():
     parser = argparse.ArgumentParser(
@@ -25,6 +28,14 @@ def main():
         description="Example: ezpp recolor -i my.png -c #00ff00"
     )
 
+    parser.add_argument(
+        "-v",
+        "-V",
+        "--version",
+        action='version',
+        version=f"EzPP v{__version__} (https://github.com/ovotop/ezpp)"
+    )
+
     subparsers = parser.add_subparsers(
         title='subcommands',
         dest='subcommands',
@@ -34,10 +45,18 @@ def main():
     # SUB COMMONDS ARGMENTS[
     global_args.add_global_argments(frosted.create_cmd_parser(subparsers))
     global_args.add_global_argments(recolor.create_cmd_parser(subparsers))
-    global_args.add_global_argments(resize.create_cmd_parser(subparsers))
-    global_args.add_global_argments(refmt.create_cmd_parser(subparsers))
-    global_args.add_global_argments(text2icon.create_cmd_parser(subparsers))
+    global_args.add_global_argments(resize.create_cmd_parser(subparsers),
+                                    has_preview=False)
+    global_args.add_global_argments(refmt.create_cmd_parser(subparsers),
+                                    has_preview=False)
+    global_args.add_global_argments(text2icon.create_cmd_parser(subparsers),
+                                    without_infile=True,
+                                    has_recursive=False,
+                                    optional_outfile=False)
     global_args.add_global_argments(shadow.create_cmd_parser(subparsers))
+    global_args.add_global_argments(render.create_cmd_parser(subparsers),
+                                    has_recursive=False,
+                                    has_overwrite=False)
     # ADD SUBCMD ARGMENTS HERE
     # SUB COMMONDS ARGMENTS]
 
