@@ -20,21 +20,13 @@ color6_re = re.compile(
 def create_cmd_parser(subparsers):
     parser_recolor = subparsers.add_parser(
         'recolor', help='recolor a pic')
-    parser_recolor.add_argument("--color",
-                                "-c",
-                                help=using_color)
+    parser_recolor.add_argument("-c", "--color", help=using_color)
 
-    parser_recolor.add_argument("--hue",
-                                "-u",
-                                help=using_hsv)
+    parser_recolor.add_argument("-u", "--hue", help=using_hsv)
 
-    parser_recolor.add_argument("--saturation",
-                                "-s",
-                                help=using_hsv)
+    parser_recolor.add_argument("-s", "--saturation", help=using_hsv)
 
-    parser_recolor.add_argument("--value",
-                                "-v",
-                                help=using_hsv)
+    parser_recolor.add_argument("-v", "--value", help=using_hsv)
 
     parser_recolor.set_defaults(on_args_parsed=_on_args_parsed)
 
@@ -49,7 +41,7 @@ def repeat2(str_tobe_repeat):
 
 def _on_args_parsed(args):
     params = vars(args)
-    infile, outfile, recursive, overwrite = global_args.parser_io_argments(
+    infile, outfile, recursive, overwrite, preview = global_args.parser_io_argments(
         params)
 
     color = params['color']
@@ -58,29 +50,30 @@ def _on_args_parsed(args):
     value = params['value']
     if hue != None or saturation != None or value != None:
         recolor_hsv(infile, outfile, recursive,
-                    overwrite, hue, saturation, value)
+                    overwrite, preview, hue, saturation, value)
         return
 
-    recolor(infile, outfile, recursive, overwrite, color)
+    recolor(infile, outfile, recursive, overwrite, preview, color)
 
 
 def deta_float(origin, deta):
     return max(min(origin + deta, 1.0), 0.0)
 
 
-def recolor_hsv(infile, outfile, recursive, overwrite, dst_h, dst_s, dst_v):
-    if recursive == None or recursive == False:
-        return recolor_hsv_file(infile, outfile, dst_h, dst_s, dst_v)
+def recolor_hsv(infile, outfile, recursive, overwrite, preview, dst_h, dst_s, dst_v):
+    if recursive == None or recursive == False or preview == True:
+        return recolor_hsv_file(infile, outfile, dst_h, dst_s, dst_v, preview)
     infiles = global_args.get_recursive_pic_infiles(infile)
     for infile_for_recursive in infiles:
         recolor_hsv_file(infile_for_recursive,
                          infile_for_recursive if overwrite else None,
                          dst_h,
                          dst_s,
-                         dst_v)
+                         dst_v,
+                         False)
 
 
-def recolor_hsv_file(infile, outfile, dst_h, dst_s, dst_v):
+def recolor_hsv_file(infile, outfile, dst_h, dst_s, dst_v, preview):
     # name of new file
     # 确定用什么样的文件名来保存图片
     # print(f"dst_h:{dst_h}, dst_s:{dst_s}, dst_v:{dst_v}")
@@ -91,7 +84,7 @@ def recolor_hsv_file(infile, outfile, dst_h, dst_s, dst_v):
     new_filename = outfile if outfile else global_args.auto_outfile(
         infile, f"_hsv{hsv_name}")
 
-    print(f"{infile} + hsv{hsv_name} -> {new_filename}")
+    print(f"FROM: {infile} + hsv{hsv_name}")
 
     # load pixel from image.
     # 打开图片，加载像素值
@@ -122,24 +115,32 @@ def recolor_hsv_file(infile, outfile, dst_h, dst_s, dst_v):
 
             px_new[x, y] = (int(255*rn), int(255*gn), int(255*bn), a)
 
-    # RGBA for png ,And RGB for other ext
-    # 如果输入文件是PNG保留RGBA格式，其他文件使用RGB格式。
-    if ext.lower == '.png':
-        img_new.save(new_filename)
+    if preview:
+        print("Preview Only")
+        img_new.show()
     else:
-        img_new.convert('RGB').save(new_filename)
+        filename, ext = os.path.splitext(infile)
+        print("TO:", new_filename)
+        # RGBA for png ,And RGB for other ext
+        # 如果输入文件是PNG保留RGBA格式，其他文件使用RGB格式。
+        if ext.lower() == '.png':
+            img_new.save(new_filename, 'PNG')
+        else:
+            img_new.convert('RGB').save(new_filename)
 
 
-def recolor(infile, outfile, recursive, overwrite, color):
-    if recursive == None or recursive == False:
-        return recolor_file(infile, outfile, color)
+def recolor(infile, outfile, recursive, overwrite, preview, color):
+    if recursive == None or recursive == False or preview == True:
+        return recolor_file(infile, outfile, preview, color)
+    infiles = global_args.get_recursive_pic_infiles(infile)
     for infile_for_recursive in infiles:
         recolor_file(infile_for_recursive,
                      infile_for_recursive if overwrite else None,
+                     False,
                      color)
 
 
-def recolor_file(infile, outfile, color):
+def recolor_file(infile, outfile, preview, color):
 
     if not is_color_re.match(color):
         print(using_color+using_hsv)
@@ -150,7 +151,6 @@ def recolor_file(infile, outfile, color):
     red = repeat2(color_m.group(1))
     green = repeat2(color_m.group(2))
     blue = repeat2(color_m.group(3))
-    bar_filename, ext = os.path.splitext(infile)
     # src_h, src_s, src_v = colorsys.rgb_to_hsv(0, 152/255, 1)
     dst_h, dst_s, dst_v = colorsys.rgb_to_hsv(
         int(red, base=16)/255,
@@ -162,7 +162,7 @@ def recolor_file(infile, outfile, color):
         infile, f"_0x{color}")
 
     print(f"hue -> {dst_h}")
-    print(f"{infile} + #{color} -> {new_filename}")
+    print(f"FROM: {infile} + #{color}")
 
     with open(infile, 'rb') as imgf:
         img = Image.open(imgf).convert('RGBA')
@@ -180,8 +180,15 @@ def recolor_file(infile, outfile, color):
             h, s, v = colorsys.rgb_to_hsv(r/255, g/255, b/255)
             rn, gn, bn = colorsys.hsv_to_rgb(dst_h, s, v)
             px_new[x, y] = (int(255*rn), int(255*gn), int(255*bn), a)
-
-    if ext.lower == '.png':
-        img_new.save(new_filename)
+    if preview:
+        print("Preview Only")
+        img_new.show()
     else:
-        img_new.convert('RGB').save(new_filename)
+        print(f"To: {new_filename}")
+        bar_filename, ext = os.path.splitext(infile)
+        # RGBA for png ,And RGB for other ext
+        # 如果输入文件是PNG保留RGBA格式，其他文件使用RGB格式。
+        if ext.lower == '.png':
+            img_new.save(new_filename)
+        else:
+            img_new.convert('RGB').save(new_filename)
